@@ -46,7 +46,7 @@ StatusBar::StatusBar(QWidget *parent)
     mMessageList = new QComboBox(this);
     mMessageList->setInsertPolicy(QComboBox::InsertAtTop);
     mMessageList->setMaxVisibleItems(5);
-    connect(mMessageList, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &StatusBar::selectLastHistory);
+    connect(mMessageList, &QComboBox::currentIndexChanged, this, &StatusBar::selectLastHistory);
     addPermanentWidget(mMessageList, 4);
 
     mLastModificationLabel = new QLabel(this);
@@ -66,7 +66,7 @@ void StatusBar::changeLineCountMessage(const QString &lineCountMessage)
     mLineCountLabel->setText(lineCountMessage);
 }
 
-void StatusBar::changeLastModification(const QTime &lastModification)
+void StatusBar::changeLastModification(QTime lastModification)
 {
     // lastModificationLabel->setText(i18n("Last updated: %1.",
     // KLocale::global()->formatTime(lastModification, true, false) ));
